#!/usr/bin/env python
#

"""Test data for saml2"""

__author__ = 'tmatsuo@example.com (Takashi MATSUO)'

TEST_STATUS_CODE = """<?xml version="1.0" encoding="utf-8"?>
<StatusCode xmlns="urn:oasis:names:tc:SAML:2.0:protocol"
  Value="urn:oasis:names:tc:SAML:2.0:status:Responder">
  <StatusCode Value="urn:oasis:names:tc:SAML:2.0:status:RequestDenied" />
</StatusCode>
"""

TEST_STATUS = """<?xml version="1.0" encoding="utf-8"?>
<Status xmlns="urn:oasis:names:tc:SAML:2.0:protocol">
  <StatusCode Value="urn:oasis:names:tc:SAML:2.0:status:Responder">
    <StatusCode Value="urn:oasis:names:tc:SAML:2.0:status:UnsupportedBinding" />
  </StatusCode>
  <StatusMessage>status message</StatusMessage>
  <StatusDetail><foo bar="bar" /></StatusDetail>
</Status>
"""

TEST_NAME_ID_POLICY = """<?xml version="1.0" encoding="utf-8"?>
<NameIDPolicy xmlns="urn:oasis:names:tc:SAML:2.0:protocol"
  Format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
  SPNameQualifier="urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
  AllowCreate="false"
/>
"""

TEST_IDP_ENTRY = """<?xml version="1.0" encoding="utf-8"?>
<IDPEntry xmlns="urn:oasis:names:tc:SAML:2.0:protocol"
  ProviderID="http://www.example.com/provider"
  Name="the provider"
  Loc="http://www.example.com/Loc"
/>
"""

TEST_IDP_LIST = """<?xml version="1.0" encoding="utf-8"?>
<IDPList xmlns="urn:oasis:names:tc:SAML:2.0:protocol">
  <IDPEntry ProviderID="http://www.example.com/provider"
    Name="the provider"
    Loc="http://www.example.com/Loc" />
  <GetComplete>http://www.example.com/GetComplete</GetComplete>
</IDPList>
"""

TEST_SCOPING = """<?xml version="1.0" encoding="utf-8"?>
<Scoping xmlns="urn:oasis:names:tc:SAML:2.0:protocol" ProxyCount="1">
  <IDPList>
    <IDPEntry ProviderID="http://www.example.com/provider"
      Name="the provider"
      Loc="http://www.example.com/Loc" />
    <GetComplete>http://www.example.com/GetComplete</GetComplete>
  </IDPList>
  <RequesterID>http://www.example.com/RequesterID</RequesterID>
</Scoping>
"""

TEST_REQUESTED_AUTHN_CONTEXT = """<?xml version="1.0" encoding="utf-8"?>
<RequestedAuthnContext xmlns="urn:oasis:names:tc:SAML:2.0:protocol"
  Comparison="exact">
  <AuthnContextClassRef xmlns="urn:oasis:names:tc:SAML:2.0:assertion">
    http://www.example.com/authnContextClassRef
  </AuthnContextClassRef>
  <AuthnContextDeclRef xmlns="urn:oasis:names:tc:SAML:2.0:assertion">
    http://www.example.com/authnContextDeclRef
  </AuthnContextDeclRef>
</RequestedAuthnContext>
"""

TEST_AUTHN_REQUEST = """<?xml version="1.0" encoding="utf-8"?>
<AuthnRequest
  ID="request id"
  Version="2.0"
  IssueInstant="2007-09-14T01:05:02Z"
  Destination="http://www.example.com/Destination"
  Consent="urn:oasis:names:tc:SAML:2.0:consent:unspecified"
  ForceAuthn="true"
  IsPassive="true"
  AssertionConsumerServiceIndex="1"
  AssertionConsumerServiceURL="http://www.example.com/acs"
  ProtocolBinding="urn:oasis:names:tc:SAML:2.0:bindings:HTTP-POST"
  AttributeConsumingServiceIndex="2"
  ProviderName="provider name"
  xmlns="urn:oasis:names:tc:SAML:2.0:protocol">
  <Issuer xmlns="urn:oasis:names:tc:SAML:2.0:assertion">
    http://www.example.com/test
  </Issuer>
  <Signature xmlns="http://www.w3.org/2000/09/xmldsig#" Id="id">
    <SignedInfo Id="id">
      <CanonicalizationMethod
        Algorithm="http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments">
      </CanonicalizationMethod>
      <SignatureMethod
        Algorithm="http://www.w3.org/2000/09/xmldsig#rsa-sha1">
        <HMACOutputLength>8</HMACOutputLength>
      </SignatureMethod>
      <Reference Id="id" URI="http://www.example.com/URI"
        Type="http://www.example.com/Type">
        <Transforms>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
        </Transforms>
        <DigestMethod Algorithm="http://www.w3.org/2000/09/xmldsig#sha1"/>
        <DigestValue>digest value</DigestValue>
      </Reference>
    </SignedInfo>
    <SignatureValue Id="id">
      signature value
    </SignatureValue>
    <KeyInfo Id="id">
      <KeyName>
        key name
      </KeyName>
      <KeyValue>
        <DSAKeyValue>
          <P>p</P>
          <Q>q</Q>
          <G>g</G>
          <Y>y</Y>
          <J>j</J>
          <Seed>seed</Seed>
          <PgenCounter>pgen counter</PgenCounter>
        </DSAKeyValue>
      </KeyValue>
      <RetrievalMethod URI="http://www.example.com/URI"
        Type="http://www.example.com/Type">
        <Transforms>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
        </Transforms>
      </RetrievalMethod>
      <X509Data>
        <X509IssuerSerial>
          <X509IssuerName>issuer name</X509IssuerName>
          <X509IssuerNumber>1</X509IssuerNumber>
        </X509IssuerSerial>
        <X509SKI>x509 ski</X509SKI>
        <X509SubjectName>x509 subject name</X509SubjectName>
        <X509Certificate>x509 certificate</X509Certificate>
        <X509CRL>x509 crl</X509CRL>
      </X509Data>
      <PGPData>
        <PGPKeyID>pgp key id</PGPKeyID>
        <PGPKeyPacket>pgp key packet</PGPKeyPacket>
      </PGPData>
      <MgmtData>
        mgmt data
      </MgmtData>
      <SPKIData>
        <SPKISexp>spki sexp</SPKISexp>
        <SPKISexp>spki sexp2</SPKISexp>
      </SPKIData>  
    </KeyInfo>
    <Object Id="object_id" Encoding="http://www.w3.org/2000/09/xmldsig#base64">
      V2VkIEp1biAgNCAxMjoxMTowMyBFRFQgMjAwMwo
    </Object>
  </Signature>
  <Extensions><test/></Extensions>
  <Subject xmlns="urn:oasis:names:tc:SAML:2.0:assertion">
    <NameID Format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
      SPProvidedID="sp provided id">
      tmatsuo@example.com
    </NameID>
    <SubjectConfirmation
      Method="urn:oasis:names:tc:SAML:2.0:cm:bearer">
      <NameID Format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
        SPProvidedID="sp provided id2">
        admin@example.com
      </NameID>
      <SubjectConfirmationData
        NotBefore="2007-08-31T01:05:02Z"
        NotOnOrAfter="2007-09-14T01:05:02Z"
        Recipient="recipient"
        InResponseTo="responseID"
        Address="127.0.0.1">
      </SubjectConfirmationData>
    </SubjectConfirmation>
  </Subject>
  <NameIDPolicy xmlns="urn:oasis:names:tc:SAML:2.0:protocol"
    Format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
    SPNameQualifier="urn:oasis:names:tc:SAML:2.0:nameid-format:persistent"
    AllowCreate="false"/>
  <Conditions
    xmlns="urn:oasis:names:tc:SAML:2.0:assertion"
    NotBefore="2007-08-31T01:05:02Z"
    NotOnOrAfter="2007-09-14T01:05:02Z">
    <Condition
      xsi:type="test"
      ExtendedAttribute="value"
      xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"/>
    <AudienceRestriction>
      <Audience>
        http://www.example.com/Audience
      </Audience>
    </AudienceRestriction>
    <OneTimeUse />
    <ProxyRestriction  Count="2">
      <Audience>http://www.example.com/Audience</Audience>
    </ProxyRestriction>
  </Conditions>
  <RequestedAuthnContext xmlns="urn:oasis:names:tc:SAML:2.0:protocol"
    Comparison="exact">
    <AuthnContextClassRef xmlns="urn:oasis:names:tc:SAML:2.0:assertion">
      http://www.example.com/authnContextClassRef
    </AuthnContextClassRef>
    <AuthnContextDeclRef xmlns="urn:oasis:names:tc:SAML:2.0:assertion">
      http://www.example.com/authnContextDeclRef
    </AuthnContextDeclRef>
  </RequestedAuthnContext>
  <Scoping xmlns="urn:oasis:names:tc:SAML:2.0:protocol" ProxyCount="1">
    <IDPList>
      <IDPEntry ProviderID="http://www.example.com/provider"
        Name="the provider"
        Loc="http://www.example.com/Loc" />
      <GetComplete>http://www.example.com/GetComplete</GetComplete>
    </IDPList>
    <RequesterID>http://www.example.com/RequesterID</RequesterID>
  </Scoping>
</AuthnRequest>
"""

TEST_LOGOUT_REQUEST = """<?xml version="1.0" encoding="utf-8"?>
<LogoutRequest
  ID="request id"
  Version="2.0"
  IssueInstant="2007-09-14T01:05:02Z"
  Destination="http://www.example.com/Destination"
  Consent="urn:oasis:names:tc:SAML:2.0:consent:unspecified"
  NotOnOrAfter="2007-10-14T01:05:02Z"
  Reason="http://www.example.com/Reason"
  xmlns="urn:oasis:names:tc:SAML:2.0:protocol">
  <Issuer xmlns="urn:oasis:names:tc:SAML:2.0:assertion">
    http://www.example.com/test
  </Issuer>
  <Signature xmlns="http://www.w3.org/2000/09/xmldsig#" Id="id">
    <SignedInfo Id="id">
      <CanonicalizationMethod
        Algorithm="http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments">
      </CanonicalizationMethod>
      <SignatureMethod
        Algorithm="http://www.w3.org/2000/09/xmldsig#rsa-sha1">
        <HMACOutputLength>8</HMACOutputLength>
      </SignatureMethod>
      <Reference Id="id" URI="http://www.example.com/URI"
        Type="http://www.example.com/Type">
        <Transforms>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
        </Transforms>
        <DigestMethod Algorithm="http://www.w3.org/2000/09/xmldsig#sha1"/>
        <DigestValue>digest value</DigestValue>
      </Reference>
    </SignedInfo>
    <SignatureValue Id="id">
      signature value
    </SignatureValue>
    <KeyInfo Id="id">
      <KeyName>
        key name
      </KeyName>
      <KeyValue>
        <DSAKeyValue>
          <P>p</P>
          <Q>q</Q>
          <G>g</G>
          <Y>y</Y>
          <J>j</J>
          <Seed>seed</Seed>
          <PgenCounter>pgen counter</PgenCounter>
        </DSAKeyValue>
      </KeyValue>
      <RetrievalMethod URI="http://www.example.com/URI"
        Type="http://www.example.com/Type">
        <Transforms>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
        </Transforms>
      </RetrievalMethod>
      <X509Data>
        <X509IssuerSerial>
          <X509IssuerName>issuer name</X509IssuerName>
          <X509IssuerNumber>1</X509IssuerNumber>
        </X509IssuerSerial>
        <X509SKI>x509 ski</X509SKI>
        <X509SubjectName>x509 subject name</X509SubjectName>
        <X509Certificate>x509 certificate</X509Certificate>
        <X509CRL>x509 crl</X509CRL>
      </X509Data>
      <PGPData>
        <PGPKeyID>pgp key id</PGPKeyID>
        <PGPKeyPacket>pgp key packet</PGPKeyPacket>
      </PGPData>
      <MgmtData>
        mgmt data
      </MgmtData>
      <SPKIData>
        <SPKISexp>spki sexp</SPKISexp>
        <SPKISexp>spki sexp2</SPKISexp>
      </SPKIData>  
    </KeyInfo>
    <Object Id="object_id" Encoding="http://www.w3.org/2000/09/xmldsig#base64">
      V2VkIEp1biAgNCAxMjoxMTowMyBFRFQgMjAwMwo
    </Object>
  </Signature>
  <Extensions><test/></Extensions>
  <BaseID xmlns="urn:oasis:names:tc:SAML:2.0:assertion"
    Format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
    SPProvidedID="sp provided id">
    tmatsuo@example.com
  </BaseID>
  <NameID xmlns="urn:oasis:names:tc:SAML:2.0:assertion"
    Format="urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress"
    SPProvidedID="sp provided id">
    tmatsuo@example.com
  </NameID>
  <EncryptedID xmlns="urn:oasis:names:tc:SAML:2.0:assertion" />
  <SessionIndex>session index</SessionIndex>
</LogoutRequest>
"""

TEST_LOGOUT_RESPONSE = """<?xml version="1.0" encoding="utf-8"?>
<LogoutResponse
  ID="response id"
  InResponseTo="request id"
  Version="2.0"
  IssueInstant="2007-09-14T01:05:02Z"
  Destination="http://www.example.com/Destination"
  Consent="urn:oasis:names:tc:SAML:2.0:consent:unspecified"
  xmlns="urn:oasis:names:tc:SAML:2.0:protocol">
  <Issuer xmlns="urn:oasis:names:tc:SAML:2.0:assertion">
    http://www.example.com/test
  </Issuer>
  <Signature xmlns="http://www.w3.org/2000/09/xmldsig#" Id="id">
    <SignedInfo Id="id">
      <CanonicalizationMethod
        Algorithm="http://www.w3.org/TR/2001/REC-xml-c14n-20010315#WithComments">
      </CanonicalizationMethod>
      <SignatureMethod
        Algorithm="http://www.w3.org/2000/09/xmldsig#rsa-sha1">
        <HMACOutputLength>8</HMACOutputLength>
      </SignatureMethod>
      <Reference Id="id" URI="http://www.example.com/URI"
        Type="http://www.example.com/Type">
        <Transforms>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
        </Transforms>
        <DigestMethod Algorithm="http://www.w3.org/2000/09/xmldsig#sha1"/>
        <DigestValue>digest value</DigestValue>
      </Reference>
    </SignedInfo>
    <SignatureValue Id="id">
      signature value
    </SignatureValue>
    <KeyInfo Id="id">
      <KeyName>
        key name
      </KeyName>
      <KeyValue>
        <DSAKeyValue>
          <P>p</P>
          <Q>q</Q>
          <G>g</G>
          <Y>y</Y>
          <J>j</J>
          <Seed>seed</Seed>
          <PgenCounter>pgen counter</PgenCounter>
        </DSAKeyValue>
      </KeyValue>
      <RetrievalMethod URI="http://www.example.com/URI"
        Type="http://www.example.com/Type">
        <Transforms>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
          <Transform Algorithm="http://www.w3.org/2000/09/xmldsig#enveloped-signature">
            <XPath>xpath</XPath>
          </Transform>
        </Transforms>
      </RetrievalMethod>
      <X509Data>
        <X509IssuerSerial>
          <X509IssuerName>issuer name</X509IssuerName>
          <X509IssuerNumber>1</X509IssuerNumber>
        </X509IssuerSerial>
        <X509SKI>x509 ski</X509SKI>
        <X509SubjectName>x509 subject name</X509SubjectName>
        <X509Certificate>x509 certificate</X509Certificate>
        <X509CRL>x509 crl</X509CRL>
      </X509Data>
      <PGPData>
        <PGPKeyID>pgp key id</PGPKeyID>
        <PGPKeyPacket>pgp key packet</PGPKeyPacket>
      </PGPData>
      <MgmtData>
        mgmt data
      </MgmtData>
      <SPKIData>
        <SPKISexp>spki sexp</SPKISexp>
        <SPKISexp>spki sexp2</SPKISexp>
      </SPKIData>  
    </KeyInfo>
    <Object Id="object_id" Encoding="http://www.w3.org/2000/09/xmldsig#base64">
      V2VkIEp1biAgNCAxMjoxMTowMyBFRFQgMjAwMwo
    </Object>
  </Signature>
  <Extensions><test/></Extensions>
  <Status>
    <StatusCode Value="urn:oasis:names:tc:SAML:2.0:status:Responder">
      <StatusCode
        Value="urn:oasis:names:tc:SAML:2.0:status:UnsupportedBinding" />
    </StatusCode>
    <StatusMessage>status message</StatusMessage>
    <StatusDetail><foo bar="bar" /></StatusDetail>
  </Status>
</LogoutResponse>
"""



#!/usr/bin/env python

#
# Generated Mon Oct 25 16:19:28 2010 by parse_xsd.py version 0.4.
#

import saml2
from saml2 import SamlBase

from saml2 import md

NAMESPACE = 'urn:oasis:names:tc:SAML:2.0:metadata:dri'


class CreationInstant(SamlBase):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:CreationInstant element """

    c_tag = 'CreationInstant'
    c_namespace = NAMESPACE
    c_value_type = {'base': 'datetime'}
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()


def creation_instant_from_string(xml_string):
    return saml2.create_class_from_xml_string(CreationInstant, xml_string)


class SerialNumber(SamlBase):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:SerialNumber element """

    c_tag = 'SerialNumber'
    c_namespace = NAMESPACE
    c_value_type = {'base': 'string'}
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()


def serial_number_from_string(xml_string):
    return saml2.create_class_from_xml_string(SerialNumber, xml_string)


class UsagePolicy(SamlBase):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:UsagePolicy element """

    c_tag = 'UsagePolicy'
    c_namespace = NAMESPACE
    c_value_type = {'base': 'anyURI'}
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()


def usage_policy_from_string(xml_string):
    return saml2.create_class_from_xml_string(UsagePolicy, xml_string)


class PublisherType_(SamlBase):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:PublisherType element """

    c_tag = 'PublisherType'
    c_namespace = NAMESPACE
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()
    c_attributes['PublisherID'] = ('publisher_id', 'md:entityIDType', True)
    c_attributes['CreationInstant'] = ('creation_instant', 'datetime', False)
    c_attributes['SerialNumber'] = ('serial_number', 'string', False)

    def __init__(self,
                 publisher_id=None,
                 creation_instant=None,
                 serial_number=None,
                 text=None,
                 extension_elements=None,
                 extension_attributes=None,
    ):
        SamlBase.__init__(self,
                          text=text,
                          extension_elements=extension_elements,
                          extension_attributes=extension_attributes,
        )
        self.publisher_id = publisher_id
        self.creation_instant = creation_instant
        self.serial_number = serial_number


def publisher_type__from_string(xml_string):
    return saml2.create_class_from_xml_string(PublisherType_, xml_string)


class RegistrationAuthority(md.EntityIDType_):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:RegistrationAuthority
    element """

    c_tag = 'RegistrationAuthority'
    c_namespace = NAMESPACE
    c_children = md.EntityIDType_.c_children.copy()
    c_attributes = md.EntityIDType_.c_attributes.copy()
    c_child_order = md.EntityIDType_.c_child_order[:]
    c_cardinality = md.EntityIDType_.c_cardinality.copy()


def registration_authority_from_string(xml_string):
    return saml2.create_class_from_xml_string(RegistrationAuthority, xml_string)


class RegistrationInstant(SamlBase):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:RegistrationInstant
    element """

    c_tag = 'RegistrationInstant'
    c_namespace = NAMESPACE
    c_value_type = {'base': 'datetime'}
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()


def registration_instant_from_string(xml_string):
    return saml2.create_class_from_xml_string(RegistrationInstant, xml_string)


class RegistrationPolicy(SamlBase):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:RegistrationPolicy
    element """

    c_tag = 'RegistrationPolicy'
    c_namespace = NAMESPACE
    c_value_type = {'base': 'anyURI'}
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()


def registration_policy_from_string(xml_string):
    return saml2.create_class_from_xml_string(RegistrationPolicy, xml_string)


class Publisher(PublisherType_):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:Publisher element """

    c_tag = 'Publisher'
    c_namespace = NAMESPACE
    c_children = PublisherType_.c_children.copy()
    c_attributes = PublisherType_.c_attributes.copy()
    c_child_order = PublisherType_.c_child_order[:]
    c_cardinality = PublisherType_.c_cardinality.copy()


def publisher_from_string(xml_string):
    return saml2.create_class_from_xml_string(Publisher, xml_string)


class RegistrationInfoType_(SamlBase):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:RegistrationInfoType
    element """

    c_tag = 'RegistrationInfoType'
    c_namespace = NAMESPACE
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()
    c_children[
        '{urn:oasis:names:tc:SAML:2.0:metadata:dri}RegistrationAuthority'] = (
    'registration_authority', RegistrationAuthority)
    c_children[
        '{urn:oasis:names:tc:SAML:2.0:metadata:dri}RegistrationInstant'] = (
    'registration_instant', RegistrationInstant)
    c_children[
        '{urn:oasis:names:tc:SAML:2.0:metadata:dri}RegistrationPolicy'] = (
    'registration_policy', RegistrationPolicy)
    c_cardinality['registration_policy'] = {"min": 0, "max": 1}
    c_child_order.extend(['registration_authority', 'registration_instant',
                          'registration_policy'])

    def __init__(self,
                 registration_authority=None,
                 registration_instant=None,
                 registration_policy=None,
                 text=None,
                 extension_elements=None,
                 extension_attributes=None,
    ):
        SamlBase.__init__(self,
                          text=text,
                          extension_elements=extension_elements,
                          extension_attributes=extension_attributes,
        )
        self.registration_authority = registration_authority
        self.registration_instant = registration_instant
        self.registration_policy = registration_policy


def registration_info_type__from_string(xml_string):
    return saml2.create_class_from_xml_string(RegistrationInfoType_, xml_string)


class PublishersType_(SamlBase):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:PublishersType element """

    c_tag = 'PublishersType'
    c_namespace = NAMESPACE
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()
    c_children['{urn:oasis:names:tc:SAML:2.0:metadata:dri}Publisher'] = (
    'publisher', [Publisher])
    c_cardinality['publisher'] = {"min": 0}
    c_child_order.extend(['publisher'])

    def __init__(self,
                 publisher=None,
                 text=None,
                 extension_elements=None,
                 extension_attributes=None,
    ):
        SamlBase.__init__(self,
                          text=text,
                          extension_elements=extension_elements,
                          extension_attributes=extension_attributes,
        )
        self.publisher = publisher or []


def publishers_type__from_string(xml_string):
    return saml2.create_class_from_xml_string(PublishersType_, xml_string)


class RegistrationInfo(RegistrationInfoType_):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:RegistrationInfo element """

    c_tag = 'RegistrationInfo'
    c_namespace = NAMESPACE
    c_children = RegistrationInfoType_.c_children.copy()
    c_attributes = RegistrationInfoType_.c_attributes.copy()
    c_child_order = RegistrationInfoType_.c_child_order[:]
    c_cardinality = RegistrationInfoType_.c_cardinality.copy()


def registration_info_from_string(xml_string):
    return saml2.create_class_from_xml_string(RegistrationInfo, xml_string)


class Publishers(PublishersType_):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:Publishers element """

    c_tag = 'Publishers'
    c_namespace = NAMESPACE
    c_children = PublishersType_.c_children.copy()
    c_attributes = PublishersType_.c_attributes.copy()
    c_child_order = PublishersType_.c_child_order[:]
    c_cardinality = PublishersType_.c_cardinality.copy()


def publishers_from_string(xml_string):
    return saml2.create_class_from_xml_string(Publishers, xml_string)


class DocumentInfoType_(SamlBase):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:DocumentInfoType element """

    c_tag = 'DocumentInfoType'
    c_namespace = NAMESPACE
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()
    c_children['{urn:oasis:names:tc:SAML:2.0:metadata:dri}CreationInstant'] = (
    'creation_instant', CreationInstant)
    c_cardinality['creation_instant'] = {"min": 0, "max": 1}
    c_children['{urn:oasis:names:tc:SAML:2.0:metadata:dri}SerialNumber'] = (
    'serial_number', SerialNumber)
    c_cardinality['serial_number'] = {"min": 0, "max": 1}
    c_children['{urn:oasis:names:tc:SAML:2.0:metadata:dri}UsagePolicy'] = (
    'usage_policy', UsagePolicy)
    c_cardinality['usage_policy'] = {"min": 0, "max": 1}
    c_children['{urn:oasis:names:tc:SAML:2.0:metadata:dri}Publishers'] = (
    'publishers', Publishers)
    c_cardinality['publishers'] = {"min": 0, "max": 1}
    c_child_order.extend(
        ['creation_instant', 'serial_number', 'usage_policy', 'publishers'])

    def __init__(self,
                 creation_instant=None,
                 serial_number=None,
                 usage_policy=None,
                 publishers=None,
                 text=None,
                 extension_elements=None,
                 extension_attributes=None,
    ):
        SamlBase.__init__(self,
                          text=text,
                          extension_elements=extension_elements,
                          extension_attributes=extension_attributes,
        )
        self.creation_instant = creation_instant
        self.serial_number = serial_number
        self.usage_policy = usage_policy
        self.publishers = publishers


def document_info_type__from_string(xml_string):
    return saml2.create_class_from_xml_string(DocumentInfoType_, xml_string)


class DocumentInfo(DocumentInfoType_):
    """The urn:oasis:names:tc:SAML:2.0:metadata:dri:DocumentInfo element """

    c_tag = 'DocumentInfo'
    c_namespace = NAMESPACE
    c_children = DocumentInfoType_.c_children.copy()
    c_attributes = DocumentInfoType_.c_attributes.copy()
    c_child_order = DocumentInfoType_.c_child_order[:]
    c_cardinality = DocumentInfoType_.c_cardinality.copy()


def document_info_from_string(xml_string):
    return saml2.create_class_from_xml_string(DocumentInfo, xml_string)


ELEMENT_FROM_STRING = {
    DocumentInfo.c_tag: document_info_from_string,
    DocumentInfoType_.c_tag: document_info_type__from_string,
    CreationInstant.c_tag: creation_instant_from_string,
    SerialNumber.c_tag: serial_number_from_string,
    UsagePolicy.c_tag: usage_policy_from_string,
    Publishers.c_tag: publishers_from_string,
    PublishersType_.c_tag: publishers_type__from_string,
    Publisher.c_tag: publisher_from_string,
    PublisherType_.c_tag: publisher_type__from_string,
    RegistrationInfo.c_tag: registration_info_from_string,
    RegistrationInfoType_.c_tag: registration_info_type__from_string,
    RegistrationAuthority.c_tag: registration_authority_from_string,
    RegistrationInstant.c_tag: registration_instant_from_string,
    RegistrationPolicy.c_tag: registration_policy_from_string,
}

ELEMENT_BY_TAG = {
    'DocumentInfo': DocumentInfo,
    'DocumentInfoType': DocumentInfoType_,
    'CreationInstant': CreationInstant,
    'SerialNumber': SerialNumber,
    'UsagePolicy': UsagePolicy,
    'Publishers': Publishers,
    'PublishersType': PublishersType_,
    'Publisher': Publisher,
    'PublisherType': PublisherType_,
    'RegistrationInfo': RegistrationInfo,
    'RegistrationInfoType': RegistrationInfoType_,
    'RegistrationAuthority': RegistrationAuthority,
    'RegistrationInstant': RegistrationInstant,
    'RegistrationPolicy': RegistrationPolicy,
}


def factory(tag, **kwargs):
    return ELEMENT_BY_TAG[tag](**kwargs)




# -*- encoding:utf-8 -*-
from mako import runtime, filters, cache
UNDEFINED = runtime.UNDEFINED
__M_dict_builtin = dict
__M_locals_builtin = locals
_magic_number = 6
_modified_time = 1367126126.936375
_template_filename='htdocs/login.mako'
_template_uri='login.mako'
_template_cache=cache.Cache(__name__, _modified_time)
_source_encoding='utf-8'
_exports = []


def _mako_get_namespace(context, name):
    try:
        return context.namespaces[(__name__, name)]
    except KeyError:
        _mako_generate_namespaces(context)
        return context.namespaces[(__name__, name)]
def _mako_generate_namespaces(context):
    pass
def _mako_inherit(template, context):
    _mako_generate_namespaces(context)
    return runtime._inherit_from(context, u'root.mako', _template_uri)
def render_body(context,**pageargs):
    context.caller_stack._push_frame()
    try:
        __M_locals = __M_dict_builtin(pageargs=pageargs)
        redirect_uri = context.get('redirect_uri', UNDEFINED)
        key = context.get('key', UNDEFINED)
        action = context.get('action', UNDEFINED)
        authn_reference = context.get('authn_reference', UNDEFINED)
        login = context.get('login', UNDEFINED)
        password = context.get('password', UNDEFINED)
        __M_writer = context.writer()
        # SOURCE LINE 1
        __M_writer(u'\n\n<h1>Please log in</h1>\n<p class="description">\n    To register it\'s quite simple: enter a login and a password\n</p>\n\n<form action="')
        # SOURCE LINE 8
        __M_writer(unicode(action))
        __M_writer(u'" method="post">\n    <input type="hidden" name="key" value="')
        # SOURCE LINE 9
        __M_writer(unicode(key))
        __M_writer(u'"/>\n    <input type="hidden" name="authn_reference" value="')
        # SOURCE LINE 10
        __M_writer(unicode(authn_reference))
        __M_writer(u'"/>\n    <input type="hidden" name="redirect_uri" value="')
        # SOURCE LINE 11
        __M_writer(unicode(redirect_uri))
        __M_writer(u'"/>\n\n    <div class="label">\n        <label for="login">Username</label>\n    </div>\n    <div>\n        <input type="text" name="login" value="')
        # SOURCE LINE 17
        __M_writer(unicode(login))
        __M_writer(u'"/><br/>\n    </div>\n\n    <div class="label">\n        <label for="password">Password</label>\n    </div>\n    <div>\n        <input type="password" name="password"\n               value="')
        # SOURCE LINE 25
        __M_writer(unicode(password))
        __M_writer(u'"/>\n    </div>\n\n    <input class="submit" type="submit" name="form.submitted" value="Log In"/>\n</form>\n')
        return ''
    finally:
        context.caller_stack._pop_frame()





from importlib_resources import path as _resource_path

from xmlschema import XMLSchema as _XMLSchema
from xmlschema.exceptions import XMLSchemaException as XMLSchemaError

import saml2.data.schemas as _data_schemas


def _create_xml_schema_validator(source, **kwargs):
    kwargs = {
        **kwargs,
        "validation": "strict",
        "locations": _locations,
        "base_url": source,
        "allow": "sandbox",
        "use_fallback": False,
    }
    return _XMLSchema(source, **kwargs)


with _resource_path(_data_schemas, "xml.xsd") as fp:
    _path_schema_xml = str(fp)
with _resource_path(_data_schemas, "envelope.xsd") as fp:
    _path_schema_envelope = str(fp)
with _resource_path(_data_schemas, "xenc-schema.xsd") as fp:
    _path_schema_xenc = str(fp)
with _resource_path(_data_schemas, "xmldsig-core-schema.xsd") as fp:
    _path_schema_xmldsig_core = str(fp)
with _resource_path(_data_schemas, "saml-schema-assertion-2.0.xsd") as fp:
    _path_schema_saml_assertion = str(fp)
with _resource_path(_data_schemas, "saml-schema-metadata-2.0.xsd") as fp:
    _path_schema_saml_metadata = str(fp)
with _resource_path(_data_schemas, "saml-schema-protocol-2.0.xsd") as fp:
    _path_schema_saml_protocol = str(fp)

_locations = {
    "http://www.w3.org/XML/1998/namespace": _path_schema_xml,
    "http://schemas.xmlsoap.org/soap/envelope/": _path_schema_envelope,
    "http://www.w3.org/2001/04/xmlenc#": _path_schema_xenc,
    "http://www.w3.org/2000/09/xmldsig#": _path_schema_xmldsig_core,
    "urn:oasis:names:tc:SAML:2.0:assertion": _path_schema_saml_assertion,
    "urn:oasis:names:tc:SAML:2.0:protocol": _path_schema_saml_protocol,
}

with _resource_path(_data_schemas, "saml-schema-assertion-2.0.xsd") as fp:
    schema_saml_assertion = _create_xml_schema_validator(str(fp))
with _resource_path(_data_schemas, "saml-schema-metadata-2.0.xsd") as fp:
    schema_saml_metadata = _create_xml_schema_validator(str(fp))
with _resource_path(_data_schemas, "saml-schema-protocol-2.0.xsd") as fp:
    schema_saml_protocol = _create_xml_schema_validator(str(fp))


node_to_schema = {
    # AssertionType
    "urn:oasis:names:tc:SAML:2.0:assertion:Assertion": schema_saml_assertion,
    # EntitiesDescriptorType
    "urn:oasis:names:tc:SAML:2.0:metadata:EntitiesDescriptor": schema_saml_metadata,
    # EntityDescriptorType
    "urn:oasis:names:tc:SAML:2.0:metadata:EntityDescriptor": schema_saml_metadata,
    # RequestAbstractType
    "urn:oasis:names:tc:SAML:2.0:protocol:AssertionIDRequest": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:SubjectQuery": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:AuthnRequest": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:ArtifactResolve": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:ManageNameIDRequest": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:LogoutRequest": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:NameIDMappingRequest": schema_saml_protocol,
    # StatusResponseType
    "urn:oasis:names:tc:SAML:2.0:protocol:Response": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:ArtifactResponse": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:ManageNameIDResponse": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:LogoutResponse": schema_saml_protocol,
    "urn:oasis:names:tc:SAML:2.0:protocol:NameIDMappingResponse": schema_saml_protocol,
}



#!/usr/bin/env python

#
# Generated Tue Jul 18 14:58:29 2017 by parse_xsd.py version 0.5.
#

import saml2
from saml2 import SamlBase

from saml2 import saml


NAMESPACE = 'http://eidas.europa.eu/saml-extensions'

class RequestedAttributeType_(SamlBase):
    """The http://eidas.europa.eu/saml-extensions:RequestedAttributeType element """

    c_tag = 'RequestedAttributeType'
    c_namespace = NAMESPACE
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()
    c_children['{urn:oasis:names:tc:SAML:2.0:assertion}AttributeValue'] = ('attribute_value', [saml.AttributeValue])
    c_cardinality['attribute_value'] = {"min":0}
    c_attributes['Name'] = ('name', 'None', True)
    c_attributes['NameFormat'] = ('name_format', 'None', True)
    c_attributes['FriendlyName'] = ('friendly_name', 'None', False)
    c_attributes['isRequired'] = ('is_required', 'None', False)
    c_child_order.extend(['attribute_value'])

    def __init__(self,
            attribute_value=None,
            name=None,
            name_format=None,
            friendly_name=None,
            is_required=None,
            text=None,
            extension_elements=None,
            extension_attributes=None,
        ):
        SamlBase.__init__(self,
                text=text,
                extension_elements=extension_elements,
                extension_attributes=extension_attributes,
                )
        self.attribute_value=attribute_value or []
        self.name=name
        self.name_format=name_format
        self.friendly_name=friendly_name
        self.is_required=is_required

def requested_attribute_type__from_string(xml_string):
    return saml2.create_class_from_xml_string(RequestedAttributeType_, xml_string)


class RequestedAttribute(RequestedAttributeType_):
    """The http://eidas.europa.eu/saml-extensions:RequestedAttribute element """

    c_tag = 'RequestedAttribute'
    c_namespace = NAMESPACE
    c_children = RequestedAttributeType_.c_children.copy()
    c_attributes = RequestedAttributeType_.c_attributes.copy()
    c_child_order = RequestedAttributeType_.c_child_order[:]
    c_cardinality = RequestedAttributeType_.c_cardinality.copy()

def requested_attribute_from_string(xml_string):
    return saml2.create_class_from_xml_string(RequestedAttribute, xml_string)


class RequestedAttributesType_(SamlBase):
    """The http://eidas.europa.eu/saml-extensions:RequestedAttributesType element """

    c_tag = 'RequestedAttributesType'
    c_namespace = NAMESPACE
    c_children = SamlBase.c_children.copy()
    c_attributes = SamlBase.c_attributes.copy()
    c_child_order = SamlBase.c_child_order[:]
    c_cardinality = SamlBase.c_cardinality.copy()
    c_children['{http://eidas.europa.eu/saml-extensions}RequestedAttribute'] = ('requested_attribute', [RequestedAttribute])
    c_cardinality['requested_attribute'] = {"min":0}
    c_child_order.extend(['requested_attribute'])

    def __init__(self,
            requested_attribute=None,
            text=None,
            extension_elements=None,
            extension_attributes=None,
        ):
        SamlBase.__init__(self,
                text=text,
                extension_elements=extension_elements,
                extension_attributes=extension_attributes,
                )
        self.requested_attribute=requested_attribute or []

def requested_attributes_type__from_string(xml_string):
    return saml2.create_class_from_xml_string(RequestedAttributesType_, xml_string)


class RequestedAttributes(RequestedAttributesType_):
    """The http://eidas.europa.eu/saml-extensions:RequestedAttributes element """

    c_tag = 'RequestedAttributes'
    c_namespace = NAMESPACE
    c_children = RequestedAttributesType_.c_children.copy()
    c_attributes = RequestedAttributesType_.c_attributes.copy()
    c_child_order = RequestedAttributesType_.c_child_order[:]
    c_cardinality = RequestedAttributesType_.c_cardinality.copy()

def requested_attributes_from_string(xml_string):
    return saml2.create_class_from_xml_string(RequestedAttributes, xml_string)


ELEMENT_FROM_STRING = {
    RequestedAttributes.c_tag: requested_attributes_from_string,
    RequestedAttributesType_.c_tag: requested_attributes_type__from_string,
    RequestedAttribute.c_tag: requested_attribute_from_string,
    RequestedAttributeType_.c_tag: requested_attribute_type__from_string,
}

ELEMENT_BY_TAG = {
    'RequestedAttributes': RequestedAttributes,
    'RequestedAttributesType': RequestedAttributesType_,
    'RequestedAttribute': RequestedAttribute,
    'RequestedAttributeType': RequestedAttributeType_,
}


def factory(tag, **kwargs):
    return ELEMENT_BY_TAG[tag](**kwargs)
